@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2009  NTT DATA CORPORATION
  *
- * Version: 1.6.6   2009/02/02
+ * Version: 1.6.7   2009/04/01
  *
  */
 #include <errno.h>
@@ -38,6 +38,8 @@ struct module;
 #include <linux/ip.h>
 #include <sched.h>
 #include <sys/ptrace.h>
+#include <sys/ioctl.h>
+#include <net/if.h>
 
 #ifndef __NR_sys_kexec_load
 #ifdef __NR_kexec_load
@@ -45,42 +47,43 @@ struct module;
 #endif
 #endif
 
-static pid_t gettid(void)
+static inline pid_t gettid(void)
 {
 	return syscall(__NR_gettid);
 }
-static int uselib(const char *library)
+static inline int uselib(const char *library)
 {
 	return syscall(__NR_uselib, library);
 }
-static caddr_t create_module(const char *name, size_t size)
+static inline caddr_t create_module(const char *name, size_t size)
 {
 	return (caddr_t) syscall(__NR_create_module, name, size);
 }
-static int pivot_root(const char *new_root, const char *put_old)
+static inline int pivot_root(const char *new_root, const char *put_old)
 {
 	return syscall(__NR_pivot_root, new_root, put_old);
 }
-static int tkill(int tid, int sig)
+static inline int tkill(int tid, int sig)
 {
 	return syscall(__NR_tkill, tid, sig);
 }
 #ifdef __NR_tgkill
-static int tgkill(int tgid, int tid, int sig)
+static inline int tgkill(int tgid, int tid, int sig)
 {
 	return syscall(__NR_tgkill, tgid, tid, sig);
 }
 #endif
 #ifdef __NR_sys_kexec_load
 struct kexec_segment;
-static long sys_kexec_load(unsigned long entry, unsigned long nr_segments,
+static inline long sys_kexec_load(unsigned long entry, unsigned long nr_segments,
 			   struct kexec_segment *segments, unsigned long flags)
 {
 	return (long) syscall(__NR_sys_kexec_load, entry, nr_segments,
 			      segments, flags);
 }
 #endif
-int reboot(int magic, int magic2, int flag, void *arg);
+/* reboot() in glibc takes just one argument. */
+int reboot(int cmd);
 int init_module(const char *name, struct module *image);
 int delete_module(const char *name);
 
@@ -123,19 +126,6 @@ static void ccs_test_pre_init(void)
 			"/sys/kernel/security/tomoyo/.process_status";
 		proc_policy_self_domain      =
 			"/sys/kernel/security/tomoyo/self_domain";
-	} else if (access("/proc/tomoyo/", F_OK) == 0) {
-		proc_policy_dir              = "/proc/tomoyo/";
-		proc_policy_domain_policy    = "/proc/tomoyo/domain_policy";
-		proc_policy_exception_policy = "/proc/tomoyo/exception_policy";
-		proc_policy_system_policy    = "/proc/tomoyo/system_policy";
-		proc_policy_profile          = "/proc/tomoyo/profile";
-		proc_policy_manager          = "/proc/tomoyo/manager";
-		proc_policy_query            = "/proc/tomoyo/query";
-		proc_policy_grant_log        = "/proc/tomoyo/grant_log";
-		proc_policy_reject_log       = "/proc/tomoyo/reject_log";
-		proc_policy_domain_status    = "/proc/tomoyo/.domain_status";
-		proc_policy_process_status   = "/proc/tomoyo/.process_status";
-		proc_policy_self_domain      = "/proc/tomoyo/self_domain";
 	}
 }
 
@@ -181,7 +171,7 @@ static void clear_status(void)
 		}
 		write(profile_fd, "=0\n", 3);
 	}
-	write(profile_fd, "255-SLEEP_PERIOD=1\n", 19);
+	//write(profile_fd, "255-SLEEP_PERIOD=1\n", 19);
 	fclose(fp);
 }
 
